<?php

namespace Slack\Blockkit\Blocks\Elements;

use Slack\Blockkit\Element;
use Slack\Exceptions\SlackSyntaxException;

final class Button extends Element
{
	protected const LIMITS = [
		'action_id' => 255,		// @todo Should be unique for each message
		'callback_id' => 255,
		'text' => 75,
		'url' => 3000,
		'value' => 2000,
	];

	public function __construct(string $text,string $value,string $action_id)
	{
		parent::__construct();

		// Defaults
		$this->type = 'button';

		$this->text = Text::item($this->validate('text',$text),'plain_text');
		$this->value = $this->validate('value',$value);
		$this->action_id = $this->validate('action_id',$action_id);
	}

	public static function item(string $text,string $value,string $action_id): self
	{
		return new self($text,$value,$action_id);
	}

	/* OPTIONAL ITEMS */

	public function confirm(Confirm $confirm): self
	{
		$this->confirm = $confirm;

		return $this;
	}

	public function style(string $string): self
	{
		if (! in_array($string,['default','primary','danger']))
			throw new SlackSyntaxException(sprintf('Unknown style %s',$string));

		$this->style = $string;

		return $this;
	}

	public function url(string $string): self
	{
		$this->url = $this->validate('url',$string);

		return $this;
	}
}