<?php

namespace Slack\Blockkit\Blocks\Elements;

use Slack\Blockkit\Element;
use Slack\Exceptions\SlackSyntaxException;

final class Confirm extends Element
{
	protected const LIMITS = [
		'title' => 100,
		'text' => 300,
		'confirm' => 30,
		'deny' => 30,
	];

	public function __construct(string $title,Text $text,string $confirm,string $deny)
	{
		parent::__construct();

		$this->title = Text::item($this->validate('title',$title),'plain_text');
		$this->text = $this->validate('text',$text->text) ? $text : NULL;
		$this->confirm = Text::item($this->validate('confirm',$confirm),'plain_text');
		$this->deny = Text::item($this->validate('deny',$deny),'plain_text');
	}

	public static function item(string $title,Text $text,string $confirm,string $deny): self
	{
		return new self($title,$text,$confirm,$deny);
	}

	public function style(string $string): self
	{
		if (! in_array($string,['default','primary','danger']))
			throw new SlackSyntaxException(sprintf('Unknown style %s',$string));

		$this->style = $string;

		return $this;
	}
}