<?php

namespace Slack\Blockkit\Blocks\Elements;

use Slack\Blockkit\Element;
use Slack\Exceptions\SlackSyntaxException;

/**
 * @note Overflow, select, and multi-select menus can only use plain_text objects,
 *       while radio buttons and checkboxes can use mrkdwn text objects
 */
final class Options extends Element
{
	protected const LIMITS = [
		'description' => 75,
		'text' => 75,
		'value' => 75,
		'url' => 3000,
	];

	public function __construct(Text $text,string $value)
	{
		parent::__construct();

		if (strlen($text->text) > self::LIMITS['text'])
			throw new SlackSyntaxException(sprintf('Text must be %d chars or less',self::LIMITS['text']));

		$this->text = $text;
		$this->value = $this->validate('value',$value);
	}

	public static function item(Text $text,string $value): self
	{
		return new self($text,$value);
	}

	/* OPTIONAL ITEMS */

	public function description(string $text): self
	{
		$this->description = Text::item($this->validate('description',$text),'plain_text');

		return $this;
	}

	public function url(string $string): self
	{
		$this->url = $this->validate('url',$string);

		return $this;
	}
}