<?php

namespace Slack\Blockkit\Blocks\Elements;

use Illuminate\Support\Collection;

use Slack\Blockkit\Element;
use Slack\Exceptions\SlackSyntaxException;

final class StaticSelect extends Element
{
	public const LIMITS = [
		'action_id' => 255,
		'placeholder' => 150,
	];

	public const MAX_OPTIONS = 100;

	// @todo option_group

	/**
	 * @param string $placeholder
	 * @param string $action_id
	 * @param Collection $options
	 * @throws SlackSyntaxException
	 * @todo We dont handle option_groups yet.
	 */
	public function __construct(string $placeholder,string $action_id,Collection $options)
	{
		parent::__construct();

		// Defaults
		$this->type = 'static_select';

		$this->placeholder = Text::item($this->validate('placeholder',$placeholder),'plain_text');
		$this->action_id = $this->validate('action_id',$action_id);

		if (! $options->count())
			throw new SlackSyntaxException('There are no options?');

		if ($options->count() > self::MAX_OPTIONS)
			throw new SlackSyntaxException(sprintf('Can only have maximum %d options',self::MAX_OPTIONS));

		$this->options = $options->transform(function($item) {
			return ['text'=>Text::item($item->name,'plain_text'),'value'=>(string)$item->value];
		});
	}

	public static function item(string $placeholder,string $action_id,Collection $options): self
	{
		return new self($placeholder,$action_id,$options);
	}

	/* OPTIONAL ITEMS */

	public function confirm(Confirm $confirm): self
	{
		$this->confirm = $confirm;

		return $this;
	}

	public function focus_on_load(bool $bool): self
	{
		$this->focus_on_load = $bool;

		return $this;
	}

	public function initial_option(string $string=NULL): self
	{
		if (! $this->options)
			throw new SlackSyntaxException('Cannot set an initial value without options defined first');

		if ($string)
			$this->initial_option = $this->options->first(function($item) use ($string) { return $item['value'] == $string; });

		return $this;
	}
}