<?php

namespace Slack\Blockkit\Blocks;

use Slack\Blockkit\{Blocks,Blocks\Elements\Text,Element};
use Slack\Exceptions\SlackSyntaxException;

final class Input extends Blocks
{
	public const LIMITS = [
		'block_id' => 255,			// @todo Should be unique for each message
		'hint' => 2000,
		'label' => 2000,
	];

	public const VALID_ELEMENTS = [
		Elements\PlainTextInput::class,
		Elements\MultiStaticSelect::class
	];

	// @todo dispatch_action

	/**
	 * @param string|null $label
	 * @throws SlackSyntaxException
	 */
	public function __construct(string $label=NULL)
	{
		parent::__construct();

		// Defaults
		$this->type = 'input';

		$this->label = Text::item($this->validate('label',$label),'plain_text');
	}

	public static function item(string $label=NULL): self
	{
		return new self($label);
	}

	public function jsonSerialize()
	{
		if (! $this->element)
			throw new SlackSyntaxException('Must define an element');

		return parent::jsonSerialize();
	}

	/* OPTIONAL ITEMS */

	public function block_id(string $string): self
	{
		$this->block_id = $this->validate('block_id',$string);

		return $this;
	}

	public function element(Element $object): self
	{
		if (! in_array(get_class($object),self::VALID_ELEMENTS))
			throw new SlackSyntaxException(sprintf('Invalid element [%s] added to input',get_class($object)));

		$this->element = $object;

		return $this;
	}

	public function hint(Elements\Text $text): self
	{
		if (strlen($text->text) > self::LIMITS['hint'])
			throw new SlackSyntaxException(sprintf('Text must be %d chars or less',self::LIMITS['hint']));

		$this->hint = $text;

		return $this;
	}

	public function optional(bool $bool): self
	{
		$this->optional = $bool;

		return $this;
	}
}